@@ -20,6 +20,9 @@ def subcluster_plot(
     cmap: str = "jet",
     spot_size: Union[float, int] = 5,
     show_axis: bool = False,
+    show_plot: bool = True,
+    cropped: bool = True,
+    margin: int = 100,
     dpi: int = 192,
     name: str = None,
     output: str = None,
@@ -66,6 +69,9 @@ def subcluster_plot(
     """
     plt.rcParams['figure.dpi'] = dpi
 
+    imagecol = adata.obs["imagecol"]
+    imagerow = adata.obs["imagerow"]
+
     if str(cluster) not in adata.obs[use_label].unique():
         raise ValueError(
             "This cluster is non-exist, please choose another cluster!")
@@ -130,7 +136,18 @@ def subcluster_plot(
     if not show_axis:
         a.axis('off')
 
-    plt.show()
+    if cropped:
+        a.set_xlim(imagecol.min() - margin,
+                imagecol.max() + margin)
+
+        a.set_ylim(imagerow.min() - margin,
+                imagerow.max() + margin)
+        
+        a.set_ylim(a.get_ylim()[::-1])
+        #plt.gca().invert_yaxis()
+
+    if show_plot:
+        plt.show()
 
     if output is not None:
         if name is None:
