@@ -25,7 +25,10 @@ def local_plot(
     spot_size: Union[float,int] = 1,
     show_color_bar: bool = True,
     show_axis: bool = False,
+    show_plot: bool = True,
     dpi: int = 180,
+    name: str = None,
+    output: str = None,
     copy: bool = False,
 ) -> Optional[AnnData]:
     
@@ -80,10 +83,11 @@ def local_plot(
     order_dict = {}
     order = 0
     for i in ref_cluster.obs["sub_cluster_labels"].unique():
-        classes_.append(i)
-        centroids_.append(adata.uns["centroid_dict"][int(i)])
-        order_dict[int(i)] = int(order)
-        order += 1
+        if len(adata.obs[adata.obs["sub_cluster_labels"] == str(i)]) > adata.uns["threshold_spots"]:
+            classes_.append(i)
+            centroids_.append(adata.uns["centroid_dict"][int(i)])
+            order_dict[int(i)] = int(order)
+            order += 1
 
     stdm = adata.uns["ST_distance_matrix"]
     non_abs_dpt = adata.uns["nonabs_dpt_distance_matrix"]
@@ -150,9 +154,19 @@ def local_plot(
 
     ax.invert_zaxis()
     ax.patch.set_visible(False) 
-    plt.show()
+    if show_plot:
+        plt.show()
+
     plt.rcParams['figure.figsize'] = 6, 4
 
+    if output is not None:
+        if name is None:
+            print("The file name is not defined!")
+            name = use_label
+        fig.savefig(output + "/" + name + ".png", dpi=dpi,
+                    bbox_inches='tight', pad_inches=0)
+    
+
 def calculate_y(m):
     import math
     mu = 0
